# eepackages

[![PyPi version](https://badgen.net/pypi/v/eepackages/)](https://pypi.com/project/eepackages)
[![CI](https://github.com/gee-community/ee-packages-py/actions/workflows/ci.yaml/badge.svg?branch=main&event=push)](https://github.com/gee-community/ee-packages-py/actions/workflows/ci.yaml)
[![CD](https://github.com/gee-community/ee-packages-py/actions/workflows/cd.yaml/badge.svg?branch=main&event=release)](https://github.com/gee-community/ee-packages-py/actions/workflows/cd.yaml)

A set of utilities built on top of Google Earth Engine (migrated from JavaScript)

This repository is basically a Python version of a set of utilities developed by me (@gena) while working with Google Earth Engine and migrated from JavaScript repository: https://code.earthengine.google.com/?accept_repo=users/gena/packages

For a GitHub clone of this package see: https://github.com/gee-community/ee-packages-js

There are not docs (yet), some of the utilities are demonstrated in the following presentation: https://docs.google.com/presentation/d/103gfl3gS8rokkrcMJV9qMBnkV7oLLbDf8ygDu6QaIZQ/edit?usp=sharing



## Usage

## Installation

## Requirements

## Compatibility

## Licence

## Authors

`eepackages` was written by `Gennadii Donchyts <gennadiy.donchyts@gmail.com>`_.

## TODO

- unit testing
- coverage
